#
# spec file for package perl-IO-Tty
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name IO-Tty
Name:           perl-IO-Tty
Version:        1.200.0
Release:        2.4
%define cpan_version 1.20
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Pseudo ttys and constants
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(IO::Pty) = %{version}
Provides:       perl(IO::Tty) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
'IO::Tty' is used internally by 'IO::Pty' to create a pseudo-tty. You
wouldn't want to use it directly except to import constants, use 'IO::Pty'.
For a list of importable constants, see IO::Tty::Constant.

Windows is now supported, but ONLY under the Cygwin environment, see
http://sources.redhat.com/cygwin/.

Please note that pty creation is very system-dependend. From my experience,
any modern POSIX system should be fine. Find below a list of systems that
'IO::Tty' should work on. A more detailed table (which is slowly getting
out-of-date) is available from the project pages document manager at
SourceForge http://sourceforge.net/projects/expectperl/.

If you have problems on your system and your system is listed in the
"verified" list, you probably have some non-standard setup, e.g. you
compiled your Linux-kernel yourself and disabled ptys (bummer!). Please ask
your friendly sysadmin for help.

If your system is not listed, unpack the latest version of 'IO::Tty', do a
''perl Makefile.PL; make; make test; uname -a'' and send me
(_RGiersig@cpan.org_) the results and I'll see what I can deduce from that.
There are chances that it will work right out-of-the-box...

If it's working on your system, please send me a short note with details
(version number, distribution, etc. 'uname -a' and 'perl -V' is a good
start; also, the output from "perl Makefile.PL" contains a lot of
interesting info, so please include that as well) so I can get an overview.
Thanks!

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README try

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Dec 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.20
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  1.20 2023-12-28 Todd Rinaldo <toddr@cpan.org>
  * #32 - Skip t/pty_get_winsize.t tests on AIX
  * #27 - Fix patchlevel check for util.h
  1.19 2023-12-28 Todd Rinaldo <toddr@cpan.org>
  * #37 - Remove --no-undefined from compiler test which is not compatible with all platforms.
* Tue Nov 28 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.18
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  1.18 2023-11-27 Todd Rinaldo <toddr@cpan.org>
  * #35 - Address Freebsd build issue: Make function checks more robust within shared lib
* Sat Nov 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.17
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  1.17 2022-11-11 Todd Rinaldo <toddr@cpan.org>
  * Switch changelog entries to metacpan friendly format
  * #29 - Fix printf format conversion specifiers in croak to support size_t on all platforms
  * #11,#30 - Tty.pm: pre-allocate buffer for ioctl but leave it length 0
  * #28 - Use $arg to match @ARGV in Makefile.PL
* Sat Jan 23 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.16
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  1.16 2021-01-2 Todd Rinaldo <toddr@cpan.org>
  * Switch to github for issue tracker.
  * Switch to testsuite CI workflow.
  * Tidy
* Wed Nov  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.15
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  2020-10-03 Todd Rinaldo <toddr@cpan.org> 1.15
  * Skip winsize test on Solaris and QNX NTO
  * Make function tests more robust
  * Work around a header name collission on util.h. This is breaking on recent OSX
* Mon Jan 20 2020 <timueller+perl@suse.de>
- updated to 1.14
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  2020-01-18 Todd Rinaldo <toddr@cpan.org> 1.14
  * Add strict/warnings to Tty.pm
  * Fix pod errors
  * Typo: s/dependend/dependent/
  * Prevent spurious warning from get_winsize()
  * Fix usage of setsid
  * Github actions testing. Windows is off of course.
  * Make README.md
  2014-12-14 Todd Rinaldo <toddr@cpan.org> 1.13_01
  * RT 91590 - Remove MAP_TARGET from Makefile.PL
  * RT 88271 - Fix for Solaris setuid when root running as other user
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.12
  see /usr/share/doc/packages/perl-IO-Tty/ChangeLog
  2014-09-12 Todd Rinaldo <toddr@cpan.org> 1.12
  * Merge pull request from Chris Williams (bingos) to fix "redefinition of typedef" errors with v5.19.4 and above
  2014-05-05 Todd Rinaldo <toddr@cpan.org>
  * Release 1.11 to CPAN with explicit dropping of support for Win32 (we never supported it) - RT 77813
  * Bump version to a devel release 1.11_01 for experimental work.
  * Fix typo in compilter - RT 75649
  * Add support for PERL_MM_OPT
* Thu Mar 31 2011 coolo@novell.com
- update to 1.10
  * CPAN testers clean. Bumping to release version 1.10
  * RT 60788 - Better error reporting on Operating Systems
    that can't set a controlling terminal e.g. BeOS
  * CPAN testers looks clean. Internal testing done on perl 5.6
  * Bump version to 1.09 and release to CPAN
  * RT 61642 - Fix file number test to work without hang on cygwin
  * Update all versions to the new version
  * RT 45008 - only try TIOCSCTTY if we don't have a ctty
  * RT 53883 - IO::Tty detection on BeOS w/fix
  * RT 60014 - better META.yml by modernizing Makefile.PL
  * RT 44771 - Add _ to list of escape characters for compiler
    so it'll compile on windows This is experimental pending a
    successful dev release
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Sep 17 2010 chris@computersalat.de
- recreated by cpanspec 1.78
* Sun Aug 30 2009 lars@linux-schulserver.de
- follow perl packaging guidelines
* Mon Jul 27 2009 mc@novell.com
- Version 1.08
  * Makefile.PL, Tty.xs: added support for posix_openpt()
* Tue Sep 19 2006 mc@suse.de
- Version 1.07
  * Tty.pm: pre-allocate buffer for ioctl
  * Tty.xs: added some more letter to BSD allocation
* Fri Jul 14 2006 mc@suse.de
- Version 1.05
  - changed newCONSTSUB to use newSV(0) instead of PL_sv_undef,
    now undef'd constants work
  - added handling for z/OS (uses /dev/ptyp0000)
  - some bugfixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Fri Jul 18 2003 mc@suse.de
- add make test
- add vendorarch changes
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Mon May 19 2003 mc@suse.de
- removed unpackaged Files from RPM_BUILD_ROOT
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Apr  5 2002 mc@suse.de
- switch to version 1.02
- removed alpha compile fix - not longer needed
- redesign of Tty.xs
- added test
- Pty.pm (spawn): rearranged setsid() and added a fresh open of
  the slave pty so the pty becomes the controlling terminal for the
  process.
- Makefile.PL: added tests for all kinds of functions and clone
  devices.
- Makefile.PL: added setting of CONFIG var
- Makefile.PL: added analysis of configuration
- Makefile.PL: fixed checks; test problematic constants with a compile.
- Makefile.PL: auto-create IO::Tty::Constant
- updated docs
* Mon Jan 28 2002 garloff@suse.de
- Compile fix for alpha.
* Wed Nov  7 2001 mc@suse.de
- switch to verion 0.05
- slave now is set to be a controlling tty if possible;
  it also remembers it's name now.
- on SCO, the slave pts* are in the /dev dir, not /dev/pts
- added test for libutil.h, util.h, pty.h and openpty()
- added symbol TIOCSCTTY
- some SVR4 only define __SVR4; fixed.
- OSF machines need termio.h for various macros
- AIX doesn't define VOIDSIG; fixed.
- Cygwin can use /dev/ptmx even though that file doesn't exist.
- moved docu over from Pty.pm to lessen confusion Pty <-> Tty
- added verified systems list
* Thu Jun 21 2001 mc@suse.de
- fixed the specfile. Used more RPM macros.
* Tue Feb 13 2001 mc@suse.de
- fixed the specfile
* Thu Feb  8 2001 mc@suse.de
- first package, v0.04
